1.1.1 (2015/04/09) Fix package content

1.1.0 (2015/04/08) Minor Adjustments
::

    + login via credentials json
    + lookup of credentials file in env and homefolder
    + upload/download inapp packages

1.0.0 (2015/03/25) First release
